#[repr(C)]pub struct DeviceGetSampleResponse {
pub value: u32,
}Fields
value: u32Trait Implementations
Sourceimpl Clone for DeviceGetSampleResponse
impl Clone for DeviceGetSampleResponse
Sourcefn clone(&self) -> DeviceGetSampleResponse
fn clone(&self) -> DeviceGetSampleResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetSampleResponse
impl Debug for DeviceGetSampleResponse
Sourceimpl<'a, ___E> Encode<DeviceGetSampleResponse, ___E> for &'a DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetSampleResponse, ___E> for &'a DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSampleResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSampleResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetSampleResponse, ___E> for DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetSampleResponse, ___E> for DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSampleResponse, DeviceGetSampleResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSampleResponse, DeviceGetSampleResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSampleResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSampleResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetSampleResponse>, ___E> for &'a DeviceGetSampleResponse
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetSampleResponse>, ___E> for &'a DeviceGetSampleResponse
Sourcefn encode_option(
this: Option<&'a DeviceGetSampleResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSampleResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceGetSampleResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSampleResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetSampleResponse>, ___E> for DeviceGetSampleResponse
impl<___E> EncodeOption<Box<'static, DeviceGetSampleResponse>, ___E> for DeviceGetSampleResponse
Sourcefn encode_option(
this: Option<DeviceGetSampleResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSampleResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceGetSampleResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSampleResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetSampleResponse> for DeviceGetSampleResponse
impl FromWire<DeviceGetSampleResponse> for DeviceGetSampleResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSampleResponse, DeviceGetSampleResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSampleResponse, DeviceGetSampleResponse>
Sourcefn from_wire(wire: DeviceGetSampleResponse) -> DeviceGetSampleResponse
fn from_wire(wire: DeviceGetSampleResponse) -> DeviceGetSampleResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetSampleResponse> for DeviceGetSampleResponse
impl FromWireRef<DeviceGetSampleResponse> for DeviceGetSampleResponse
Sourcefn from_wire_ref(wire: &DeviceGetSampleResponse) -> DeviceGetSampleResponse
fn from_wire_ref(wire: &DeviceGetSampleResponse) -> DeviceGetSampleResponse
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetSampleResponse
impl Hash for DeviceGetSampleResponse
Sourceimpl Ord for DeviceGetSampleResponse
impl Ord for DeviceGetSampleResponse
Sourcefn cmp(&self, other: &DeviceGetSampleResponse) -> Ordering
fn cmp(&self, other: &DeviceGetSampleResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetSampleResponse
impl PartialEq for DeviceGetSampleResponse
Sourceimpl PartialOrd for DeviceGetSampleResponse
impl PartialOrd for DeviceGetSampleResponse
impl Copy for DeviceGetSampleResponse
impl Eq for DeviceGetSampleResponse
impl StructuralPartialEq for DeviceGetSampleResponse