#[repr(C)]pub struct DeviceGetResolutionResponse {
pub resolution: u8,
}Expand description
The wire type corresponding to DeviceGetResolutionResponse.
Fields
resolution: u8Trait Implementations
Sourceimpl Clone for DeviceGetResolutionResponse
impl Clone for DeviceGetResolutionResponse
Sourcefn clone(&self) -> DeviceGetResolutionResponse
fn clone(&self) -> DeviceGetResolutionResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetResolutionResponse
impl Constrained for DeviceGetResolutionResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetResolutionResponse>,
_: <DeviceGetResolutionResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetResolutionResponse>, _: <DeviceGetResolutionResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceGetResolutionResponse
impl Debug for DeviceGetResolutionResponse
Sourceimpl<___D> Decode<___D> for DeviceGetResolutionResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetResolutionResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetResolutionResponse, ___E> for &'a DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetResolutionResponse, ___E> for &'a DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetResolutionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetResolutionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetResolutionResponse, ___E> for DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetResolutionResponse, ___E> for DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetResolutionResponse, DeviceGetResolutionResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetResolutionResponse, DeviceGetResolutionResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetResolutionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetResolutionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetResolutionResponse, ___E> for DeviceGetResolutionResponse<T0>
impl<___E, T0> Encode<DeviceGetResolutionResponse, ___E> for DeviceGetResolutionResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetResolutionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetResolutionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
impl FromWire<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetResolutionResponse, DeviceGetResolutionResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetResolutionResponse, DeviceGetResolutionResponse>
Sourcefn from_wire(wire: DeviceGetResolutionResponse) -> DeviceGetResolutionResponse
fn from_wire(wire: DeviceGetResolutionResponse) -> DeviceGetResolutionResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
impl FromWireRef<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
Sourcefn from_wire_ref(
wire: &DeviceGetResolutionResponse,
) -> DeviceGetResolutionResponse
fn from_wire_ref( wire: &DeviceGetResolutionResponse, ) -> DeviceGetResolutionResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetResolutionResponse
impl IntoNatural for DeviceGetResolutionResponse
Sourcetype Natural = DeviceGetResolutionResponse
type Natural = DeviceGetResolutionResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetResolutionResponse
impl Wire for DeviceGetResolutionResponse
Sourcetype Narrowed<'de> = DeviceGetResolutionResponse
type Narrowed<'de> = DeviceGetResolutionResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetResolutionResponse>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetResolutionResponse>)
Writes zeroes to the padding for this type, if any.